@@ -3,10 +3,10 @@ context("whiten")
 test_that("`whiten` whiten data", {
   data <- data.frame(id = 1:10, x = rnorm(10), y = rnorm(10), z = rnorm(10))
 
-  db <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")
-
-  # https://github.com/tidyverse/dplyr/issues/3093
-  RSQLite::initExtension(db)
+  db <- DBI::dbConnect(RSQLite::SQLite(),
+    ":memory:",
+    loadable.extensions = TRUE
+  )
 
   data <- dplyr::copy_to(db, data)
 
